| hymet_L0_flat | R Documentation |
A fully joined and flat version of EDI data package knb-lter-mcm.9003.11 (Seasonal high-frequency measurements of discharge, water temperature, and specific conductivity from Andersen Creek at H1, McMurdo Dry Valleys, Antarctica (1993-2020, ongoing)) with all relevant hymetDP L1 identifiers and content added. Use this dataset as an input to the L0_flat argument of the "create" functions.
hymet_L0_flat
A data frame with 30,000 rows and 45 variables:
Local datetime
Local timezone offset from UTC
Datetime in UTC
Variable name from the L0 dataset
Numeric value of the observation
Code of a qualifier (flag)
Unit name from the L0 dataset
The data value ID
The variable ID
The ODM CV variable name
The ODM CV unit name for the variable
The ODM CV sample medium name
The ODM CV value type
Whether the values are from a regularly sampled dataset
Temporal footprint of samples
The ODM CV unit name for time support
The ODM CV data type
The ODM CV general category
The numeric value used to encode not available data
The method ID
The description of the method
The site ID
The name of the site
Latitude of site
Longitude of site
Elevation of site in meters
The ODM CV site type
Name of organization that collected the data
Name of contact person for the data source
Email of contact
The source ID
The description of the source data
URL of source data
Citation for the source data
Contact phone
Contact physical address
Contact city
Contact state if in US, otherwise full country name
Contact postal code
The quality control ID
Definition of the quality control level
Explanation of the quality control level
The qualifier ID
Description of the qualifier
https://portal.edirepository.org/nis/mapbrowse?scope=knb-lter-mcm&identifier=9003&revision=11
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.