| read_tables | R Documentation |
Read data tables of a data package from the EML metadata.
read_tables( eml, strip.white = FALSE, na.strings = NULL, convert.missing.value = NULL, add.units = FALSE, table.names = NULL )
eml |
(xml_document, xml_node) EML metadata returned from
|
strip.white |
(logical) Strips leading and trailing whitespaces of unquoted fields. Default if FALSE. |
na.strings |
(character) Strings to be interpreted as NA. Setting
|
convert.missing.value |
(logical) Converts all missing value codes
specified in |
add.units |
(logical) If TRUE, a variable's unit of measurement will be
added to the table in a separate column with a column name of the form:
|
table.names |
(character) Character vector of one or more table names
( |
This function uses data.table::fread() and uses default
argument values if the EML based values return an error.
Default settings preserve the form the data were originally published in.
(list) List of named data frames
## Not run:
eml <- read_metadata('knb-lter-mcm.9003.11')
tables <- read_tables(
eml = eml,
strip.white = TRUE,
na.strings = "",
convert.missing.value = TRUE,
add.units = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.